# -*- coding: utf-8 -*-
"""
Created on Thu Apr 20 15:28:55 2023
@author: Patricia Buffon
"""

#This code (*.py) opens the raw data, converts the image coordinates of the profiles into the chosen Cartesian coordinate system, interpolates the data linearly (1st order, feeling in nan values), subctracts from each profile the initial bed level (profile at t=0 s), and finally, plots the resulting profiles. 
#Please note this code does not include the second order interpolation used in a small portion of the scour hole area in order to determine its maximum depth properties more accurately.   
  
# Import libraries:
import os
import numpy as np
import csv
from matplotlib import pyplot as plt
from scipy.interpolate import griddata
import scipy.interpolate as sp
import matplotlib as mpl

######### NAME OF EXPERIMENT

#name="00_EXP_Q1_J45_S00"
#name="01_EXP_Q2_J45_S00"
name="02_EXP_Q3_J45_S00"
#name="03_EXP_Q4_J45_S00"
#name="04_EXP_Q5_J45_S00"
#name="05_EXP_Q3_J35_S00"
#name="06_EXP_Q3_J55_S00"
#name="07_EXP_Q3_J45_S03"
#name="08_EXP_Q3_J45_S10"
#name="09_EXP_Q3_J45_S17"
                     
######## TIME
pathName = os.getcwd()+'\\02 TIME'
time_bed = open(os.path.join(pathName, 'time_bed_' + name +'.csv'))
reader_time_bed = csv.reader(time_bed, quoting=csv.QUOTE_NONNUMERIC)
TIME_bed = []
for row in reader_time_bed:
    TIME_bed.append(row)    
time_bed = np.array(TIME_bed)

######### COORDINATES
pathName = os.getcwd()+'\\03 COORDINATES'
coordinates = open(os.path.join(pathName, 'coordinates_' +name +'.csv'))
reader_coordinates = csv.reader(coordinates, quoting=csv.QUOTE_NONNUMERIC)
coordinates = []
for row in reader_coordinates: 
    coordinates.append(row)             
xpixel=np.array(coordinates)[:,0]
ypixel=np.array(coordinates)[:,1]
xcm=np.array(coordinates)[:,2]
ycm=np.array(coordinates)[:,3]

######## PROFILE AT TIME = 0 (INITIAL BED LEVEL)
pathName = os.getcwd()+'\\01 BED LEVEL\\'+name
file_zero = open(os.path.join(pathName, '0s_bed.csv'))
reader_zero = csv.reader(file_zero, quoting=csv.QUOTE_NONNUMERIC)
zero=[]
for row in reader_zero:
    zero.append(row)

# convert coordinate system
xzero=range(3840) 
yzero=np.array(zero)[:,0]
grid_xzero = griddata((xpixel,ypixel), xcm, (xzero, yzero), method='linear')
grid_yzero = griddata((xpixel,ypixel), ycm, (xzero, yzero), method='linear')

# 1st order interpolation
X=np.linspace(-70, 330, 3840)
interpolationzero=sp.interp1d(grid_xzero, grid_yzero, kind='linear',bounds_error=False)
Yzero=interpolationzero(X)

######## BED LEVEL PROFILES
pathName = os.getcwd()+'\\01 BED LEVEL\\'+name
numFiles_bed = []
fileNames_bed = sorted(os.listdir(pathName),key=len)
for fileNames in fileNames_bed:
    if fileNames.endswith(".csv"):
        numFiles_bed.append(fileNames)
        
N=len(numFiles_bed)
ARR_bed=np.zeros([3840,N]) 
for i in range(0, N):           
    pathName_bed = os.getcwd()+'\\01 BED LEVEL\\'+name
    results_bed=[]
    file_bed = open(os.path.join(pathName_bed, numFiles_bed[i]), "rU")
    reader_bed = csv.reader(file_bed, quoting=csv.QUOTE_NONNUMERIC)
    for row in reader_bed:
        results_bed.append(row)                 
    
    # convert coordinate system
    x=range(3840)
    y_bed=np.array(results_bed)[:,0]
    grid_x_bed = griddata((xpixel,ypixel), xcm, (x, y_bed), method='linear')
    grid_y_bed = griddata((xpixel,ypixel), ycm, (x, y_bed), method='linear')
  
    # 1st order interpolation
    interpolation_bed=sp.interp1d(grid_x_bed, grid_y_bed, kind='linear', bounds_error=False)
    Y_bed=interpolation_bed(X)                      
    
    # subtract initial bed level
    ARR_bed[:,i] = Y_bed[:] - Yzero
    
######## PLOT BED LEVEL PROFILES
unit_y='$y$'+"    (cm)"
unit_x='$x$'+"    (cm)"
limit_y=(-40,20)
limit_x=(-70,330)

plt.figure()
cmap = mpl.cm.copper
cmap = cmap.reversed(mpl.cm.copper)
norm = mpl.colors.Normalize(vmin=0, vmax=650)
sm = plt.cm.ScalarMappable(cmap=cmap, norm=norm)
sm.set_array([])

for i in range(0, N):
    plt.plot(X, ARR_bed[:, i], lw=0.7, color=sm.to_rgba(int(time_bed[i])))   
      
cbar = plt.colorbar(sm, ax=plt.gca())
cbar.set_label(label='t (s)',size=16)
cbar.ax.tick_params(labelsize=14)
plt.ylim(limit_y)
plt.xlim(limit_x)
plt.xlabel(unit_x, fontsize='16',labelpad=0)
plt.ylabel(unit_y, fontsize='16',labelpad=0)
plt.yticks(fontsize=14)
plt.xticks(fontsize=14)
plt.grid(b=True, which='major', color='k', linestyle='-', alpha=0.1)
displayed_name = name[7:]
plt.text(0.78, 0.065, displayed_name, fontsize=16,transform=plt.gca().transAxes, ha='center',bbox=dict(facecolor='white', edgecolor='black', boxstyle='round,pad=0.3'))
plt.tight_layout()
plt.show()













